-- Please load and run this patch in SQL Server Management Studio (SSMS)
-- after you have copied all the .sql files that came with the patch
-- (including this file) into C:\temp on the server hosting BestDR12.
 
-- This patch loads AnicllargyTarget2 values and fixes fAncillaryTarget?N
-- functions for DR12, creates new function fSDSSfromSpecID, and updates 
-- how DataServerURL, WebServerURL and Description are set in SiteConstants
-- table by spSetVersion. Needs the files DataConstants.sql,
-- ConstantSupport.sql and spFinish.sql to be present in C:\Temp\ dir on
-- the DB server where this patch is run (in SSMS). You also need to be 
-- a DB admin user in order to turn the xp_cmdshell permissions on.
--     - Ani Thakar, May 29, 2015

USE [BestDR12]
GO



-- Create new function fSDSSfromSpecID (PR #2257) as inverse of 
-- fSpecIDfromSDSS.

--===============================================
IF EXISTS (SELECT name FROM   sysobjects 
	   WHERE  name = N'fSDSSfromSpecID' )
	DROP FUNCTION fSDSSfromSpecID
GO
--
CREATE FUNCTION fSDSSfromSpecID(@specID bigint)
-------------------------------------------------------------------------------
--/H Returns a table pf the 3-part SDSS numbers from the long specObjID.
--
--/T The returned columns in the output table are: 
--/T	plate, mjd, fiber<br>
--/T <samp> select * from dbo.fSDSSfromSpecID(865922932356966400)</samp>
-------------------------------------------------------------------------------
RETURNS @sdssSpecID TABLE (
	plate INT,
	mjd INT,
	fiber INT
)
AS BEGIN
    INSERT @sdssSpecID 
	SELECT
	    cast( (@specID / power(cast(2 as bigint),50)) AS INT ) AS plate,
	    cast( (((@specID & 0x0000003FFFFFFFFF)/ power(cast(2 as bigint),24)) + 50000) AS INT ) AS mjd,
	    cast( (((@specID & 0x0003FFFFFFFFFFFF) / power(cast(2 as bigint),38))) AS INT) AS fiber
    RETURN
END
GO
--



-- Start by enabling the cmd shell.
EXEC sp_configure 'show advanced options', 1
GO
RECONFIGURE WITH OVERRIDE
GO
EXEC sp_configure 'xp_cmdshell', 1
GO
RECONFIGURE WITH OVERRIDE
GO


-- Reload the data constants and support functions, and fSDSSfromSpecID.
-- The RunSQLScript will write diagnostics outout to a file in the same
-- directory (C:\Temp\BestDR12schemaSync.txt).
EXEC spRunSQLScript 0, 0, 'Sync Schema', 'C:\Temp', 'DataConstants.sql','BestDR12','C:\temp\BestDR12schemaSync.txt' 
EXEC spRunSQLScript 0, 0, 'Sync Schema', 'C:\Temp', 'ConstantSupport.sql','BestDR12','C:\temp\BestDR12schemaSync.txt' 
EXEC spRunSQLScript 0, 0, 'Sync Schema', 'C:\Temp', 'spFinish.sql','BestDR12','C:\temp\BestDR12schemaSync.txt' 

-- Recreate index lost in previous step
EXEC spIndexBuildSelection 0,0, 'K', 'PHOTO'	-- for stripeDefs index


-- Refresh metadata tables
EXEC spLoadMetaData 0,0, 'C:\Temp', 1


-- Disable the cmd shell privileges.
EXEC sp_configure 'xp_cmdshell', 0
GO
RECONFIGURE WITH OVERRIDE
GO


-- Manually insert entry into Versions for previous patch (which is included
--  in this script).  This is not strictly necessary but just for completeness.
DELETE FROM Versions WHERE version='12.5'
GO
DELETE FROM Versions WHERE version='12.6'
GO
INSERT Versions(event,previous,checksum,version,description,text,who,[when])
VALUES ('Update DR12','12.4','83126551915','12.5','DR12 constantss patch','Update DataConstants for AncillaryTarget values and functions','A.Thakar','Mar 25 2015 4:05PM')
GO



-- Modify spSetVersion so that it updates the Description and URL fields
-- correctly based on the current DR.

ALTER PROCEDURE spSetVersion(@taskid int, @stepid int,
		@release varchar(8)='4', 
		@dbversion varchar(128)='v4_18', 
		@vname varchar(128)='Initial version of DR', 
		@vnum varchar(8)='.0',
                @vdesc varchar(128)='Incremental load',
                @vtext varchar(4096)=' ',
		@vwho varchar(128) = ' ')
---------------------------------------------------
--/H Update the checksum and set the version info for this DB.
--/A -------------------------------------------------
--/T 
--/T 
--/T 
--/T 
---------------------------------------------------
AS
BEGIN
	-- Check schema skew
	EXEC spCheckDBObjects
	EXEC spCheckDBColumns
	EXEC spCheckDBIndexes

	-- Update statistics for all tables
	EXEC spUpdateStatistics

	-- generate diagnostics and checksum
	EXEC spMakeDiagnostics
	EXEC spUpdateSkyServerCrossCheck
	EXEC spCompareChecksum

	DECLARE @curtime VARCHAR(64), @prev VARCHAR(32)

	SET @curtime=CAST( GETDATE() AS VARCHAR(64) );

	-- update SiteConstants table
	UPDATE siteconstants SET value='http://dr'+@release+'.sdss3.org/' WHERE name='DataServerURL'
	UPDATE siteconstants SET value='http://skyserver.sdss.org/dr'+@release+'/en/' WHERE name='WebServerURL'
	UPDATE siteconstants SET value=@release+@vnum WHERE name='DB Version'
	UPDATE siteconstants SET value=@dbversion WHERE name='Schema Version'
	UPDATE siteconstants SET value='DR'+@release+' SkyServer' WHERE name='DB Type'
	UPDATE siteconstants SET comment='from Data Release '+@release+' of the Sloan Digital Sky Survey (http://www.sdss.org/dr'+@release+'/).' WHERE name='Description'

	-- get checksum from site constants and add new entry to Versions
	DECLARE @checksum VARCHAR(64)
	SELECT @checksum=value FROM siteconstants WHERE [name]='Checksum'
	SELECT TOP 1 @prev=version from Versions order by convert (datetime,[when]) desc

	-- update Versions table with latest version
	INSERT Versions
		VALUES( @vname+@release,@prev,@checksum,@release+@vnum,
			@vdesc, @vtext, @vwho, @curtime)
END
GO



-- Now update the DB version. This will typically take a long time (hours) 
-- to finish because of the diagnostics it computes on all the data in the
-- db.
EXECUTE spSetVersion
  0
  ,0
  ,'12'
  ,'162560'
  ,'Update DR'
  ,'.6'
  ,'DR12 patch for v6'
  ,'Add fSDSSfromSpecID (PR 2257) and update spSetVersion'
  ,'A.Thakar'
GO

